Package: antaresViz
Type: Package
Title: Antares Visualizations
Version: 0.18.3
Authors@R: c(
    person("Tatiana", "Vargas", email = "tatiana.vargas@rte-france.com", role = c("aut", "cre")),
    person("Jalal-Edine", "Zawam", role = "ctb"),
    person("Francois", "Guillem", role = "ctb"),
    person("Benoit", "Thieurmel", role = "ctb"),
    person("Titouan", "Robert", role = "ctb"),
    person("Paul", "Plessiez", role = "ctb"),
    person("Baptiste", "Seguinot", role = "ctb"),
    person("RTE", role = "cph")
    )
Description: Visualize results generated by Antares, a powerful open source software
    developed by RTE to simulate and study electric power systems
    (more information about 'Antares' here: <https://github.com/AntaresSimulatorTeam/Antares_Simulator>).
    This package provides functions that create interactive charts to help
    'Antares' users visually explore the results of their simulations.
URL: https://github.com/rte-antares-rpackage/antaresViz
BugReports: https://github.com/rte-antares-rpackage/antaresViz/issues
License: GPL (>= 3)
Encoding: UTF-8
Depends: antaresRead (>= 2.2.9), antaresProcessing (>= 0.13.0), spMaps
        (>= 0.5.0)
Imports: dygraphs (>= 1.1.1.6), shiny (>= 0.13.0), plotly (>= 4.5.6),
        htmltools, htmlwidgets (>= 0.7.0), manipulateWidget (>=
        0.10.0), leaflet (>= 1.1.0), sp (>= 2.0-0), sf, webshot,
        data.table, methods, lubridate, geojsonio, graphics, stats,
        leaflet.minicharts (>= 0.5.3), assertthat, rAmCharts, utils,
        lifecycle
RoxygenNote: 7.2.2
Suggests: testthat, covr, ggplot2, knitr, visNetwork, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2024-11-29 14:01:10 UTC; berthetcle
Author: Tatiana Vargas [aut, cre],
  Jalal-Edine Zawam [ctb],
  Francois Guillem [ctb],
  Benoit Thieurmel [ctb],
  Titouan Robert [ctb],
  Paul Plessiez [ctb],
  Baptiste Seguinot [ctb],
  RTE [cph]
Maintainer: Tatiana Vargas <tatiana.vargas@rte-france.com>
Repository: CRAN
Date/Publication: 2024-12-02 10:00:19 UTC
Built: R 4.6.0; ; 2026-04-30 07:05:07 UTC; unix
