# Generated by roxygen2: do not edit by hand

S3method(plot,antaresData)
S3method(plot,list)
S3method(plot,mapLayout)
S3method(plot,simOptions)
export(addShadows)
export(colorScaleOptions)
export(defaultTilesURL)
export(exchangesStack)
export(exchangesStackAliases)
export(getInteractivity)
export(leafletDragPointsOutput)
export(limitSizeGraph)
export(mapLayout)
export(modRpart)
export(modXY)
export(plotMap)
export(plotMapLayout)
export(plotMapOptions)
export(plotThermalGroupCapacities)
export(plotXY)
export(prodStack)
export(prodStackAliases)
export(prodStackExchangesLegend)
export(prodStackLegend)
export(renderLeafletDragPoints)
export(runAppAntaresViz)
export(savePlotAsPng)
export(setExchangesStackAlias)
export(setInteractivity)
export(setProdStackAlias)
export(stackMap)
export(tsLegend)
export(tsPlot)
import(antaresProcessing)
import(antaresRead)
import(assertthat)
import(data.table)
import(dygraphs)
import(htmltools)
import(leaflet)
import(leaflet.minicharts)
import(manipulateWidget)
import(rAmCharts)
import(sf)
import(shiny)
import(sp)
import(spMaps)
importFrom(geojsonio,geojson_json)
importFrom(grDevices,col2rgb)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,colors)
importFrom(grDevices,gray)
importFrom(grDevices,rainbow)
importFrom(grDevices,rgb)
importFrom(graphics,par)
importFrom(graphics,plot.default)
importFrom(lifecycle,deprecate_warn)
importFrom(lifecycle,deprecated)
importFrom(lifecycle,is_present)
importFrom(methods,is)
importFrom(plotly,add_bars)
importFrom(plotly,add_heatmap)
importFrom(plotly,add_text)
importFrom(plotly,add_trace)
importFrom(plotly,config)
importFrom(plotly,layout)
importFrom(plotly,plot_ly)
importFrom(shiny,runApp)
importFrom(stats,as.formula)
importFrom(stats,density)
importFrom(stats,lm)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(utils,capture.output)
importFrom(utils,object.size)
